% Compute flow-law items and velocities in inland ice sheet portion of mesh
% This version allows two values for C_sliding - over hard/soft beds
%for n=1:icelev
%kice(:,n)=kiceconstant*ones(nods,1);
%capice(:,n)=ciceconstant*ones(nods,1);
%kice(:,n)=(3.101e8/(60*60*24*365.24))*exp(-0.0057*T(:,n+rocklev)) ;
%capice(:,n)=(2115.3*ones(nods,1) + 7.79293*(T(:,n+rocklev)-273.15*ones(nods,1))); % From Huybrechts, and previously from Ritz
%end


meltedbar=( melted(index(:,1)) | melted(index(:,2)) );
sbar=(s(index(:,1)*2-1)+s(index(:,2)*2-1))/2;
bbar=(b(index(:,1)*2-1)+b(index(:,2)*2-1))/2;
grads2=((s(index(:,2)*2-1) - s(index(:,1)*2-1))./Le).^2;
grads2node=s(2:2:nods*2).^2;
sxbar=(s(index(:,1)*2)+s(index(:,2)*2))/2;

dz=zeros(nel,icelev-1);
dznode=zeros(nods,icelev-1);
for lev=1:icelev-1
dz(:,lev)=thickbar*dzeta(lev); % note that this is an average over the element
dznode(:,lev)=thick(1:2:nods*2-1)*dzeta(lev); 
end



for n=2:icelev

Ibar(:,n)=E*grads2.*((rho*g)^2) ...
   .*(Abar(:,n-1).*(thickbar.*(1-zetaice(n-1))).^3 + ...
   Abar(:,n).*(thickbar.*(1-zetaice(n))).^3).*dz(:,n-1)/2 + Ibar(:,n-1);

Inode(:,n)=E*grads2node.*((rho*g)^2) ...
   .*(Anode(:,n-1).*(thick(1:2:nods*2).*(1-zetaice(n-1))).^3 + ...
   Anode(:,n).*(thick(1:2:nods*2).*(1-zetaice(n))).^3).*dznode(:,n-1)/2 + Inode(:,n-1);

udefnode(:,n)= -2*rho*g*Inode(:,n).*s(2:2:nods*2);
udefbar(:,n)= -2*rho*g*Ibar(:,n).*sxbar;

%%The below logic was added so that the deformation at any terminus would equal
%%the deformation at the next node upstream rather than zero and so that the deformation
%%at two merging terminii would equal the sum of the upstream values in both directions...
%%one being positive and one negative.

udefnode(2:nods-1,n)=(barren(3:2:nods*2-3)==barren(4:2:nods*2-2)).*udefnode(2:nods-1,n) ...
   + (barren(1:2:nods*2-5)==0 & barren(3:2:nods*2-3)==1).*udefnode(1:nods-2,n) ...
   + (~(barren(3:2:nods*2-3)==barren(4:2:nods*2-2)) & (barren(1:2:nods*2-5)==1 ...
   & barren(4:2:nods*2-2)==0)).*udefnode(3:nods,n) ...
   + ((barren(1:2:nods*2-5)==0 & barren(3:2:nods*2-3)==1 & barren(5:2:nods*2-1)==0) ...
   & (~(barren(3:2:nods*2-3)==barren(4:2:nods*2-2)))).*(udefnode(3:nods,n)+udefnode(1:nods-2,n));
   
   
udefnode(1,n)=(barren(1)==barren(2))*udefnode(1,n) ...
   + (~(barren(1)==barren(2))).*udefnode(2,n);

udefnode(nods,n)=(barren(2*nods-1)==barren(2*nods))*udefnode(nods,n) ...
   + (~(barren(2*nods-1)==barren(2*nods))).*udefnode(nods-1,n);
   

end


%%*****************
%%For research with one bed sliding parameter...
uslidebar=-C_sliding.*rho.*g.*thickbar.*sxbar.*meltedbar; % basalsliding
uslidenode=-C_sliding.*rho.*g.*thick(1:2:nods*2).*s(2:2:nods*2).*melted; % basalsliding
%Logic to prohibit sliding at isolated nodes after allowing for terminus-upstream-node linking
%and two merging terminii linking such that would equal the sum of the upstream values in both directions...
%%one being positive and one negative....
uslidenode(2:nods-1)=(barren(1:2:nods*2-5)==0 & barren(3:2:nods*2-3)==1).*uslidenode(1:nods-2) ...
  + (barren(3:2:nods*2-3)==barren(4:2:nods*2-2)).*uslidenode(2:nods-1) ...
  + (~(barren(3:2:nods*2-3)==barren(4:2:nods*2-2)) & (barren(1:2:nods*2-5)==1 ...
  & barren(4:2:nods*2-2)==0)).*uslidenode(3:nods) ...
  + ((barren(1:2:nods*2-5)==0 & barren(3:2:nods*2-3)==1 & barren(5:2:nods*2-1)==0) ...
  & (~(barren(3:2:nods*2-3)==barren(4:2:nods*2-2)))).*(uslidenode(3:nods)+uslidenode(1:nods-2));
  

uslidenode(1)=(barren(1)==barren(2))*uslidenode(1) ...
  + (~(barren(1)==barren(2))).*uslidenode(2);

uslidenode(nods)=(barren(2*nods-1)==barren(2*nods))*uslidenode(nods) ...
  + (~(barren(2*nods-1)==barren(2*nods))).*uslidenode(nods-1);

uslidenode(2:nods-1)=uslidenode(2:nods-1).*( (melted(1:nods-2) & melted(2:nods-1)) | (melted(2:nods-1) & melted(3:nods)) ); % prohibit sliding at isolated nodes
uslidenode(1)=uslidenode(1).*(melted(1) & melted(2) ); % prohibit sliding at isolated nodes
uslidenode(nods)=uslidenode(nods).*(melted(nods-1) & melted(nods)); % prohibit sliding at isolated nodes

%%****************


%****************
%For research with variable bed lubrications......
%Paul's version of last 5 lines (for variable C_sliding) with Byron's corrections
%uslidenode=-C_sliding1.*(Xposition(:)<Xcontr).*rho.*g.*thick(1:2:nods*2).*s(2:2:nods*2).*melted -C_sliding2.*(Xposition(:)>=Xcontr).*rho.*g.*thick(1:2:nods*2).*s(2:2:nods*2).*melted; % basalsliding

% %%%%Sliding dependent everywhere on T
% uslidebar=-C_sliding1.*((Xcontr(1)<=Xposition(1:nel) & Xposition(1:nel)<Xcontr(2)) | (Xcontr(3)<=Xposition(1:nel) & Xposition(1:nel)<Xcontr(4))).*rho.*g.*thickbar.*sxbar.*meltedbar ...
% -C_sliding2.*((Xposition(1:nel)<Xcontr(1)) | (Xcontr(2)<=Xposition(1:nel) & Xposition(1:nel)<Xcontr(3)) | (Xcontr(4)<=Xposition(1:nel))).*rho.*g.*thickbar.*sxbar.*meltedbar; % basalsliding
% 
% uslidenode=-C_sliding1.*((Xcontr(1)<=Xposition(:) & Xposition(:)<Xcontr(2)) | (Xcontr(3)<=Xposition(:) & Xposition(:)<Xcontr(4))).*rho.*g.*thick(1:2:nods*2).*s(2:2:nods*2).*melted ...
% -C_sliding2.*((Xposition(:)<Xcontr(1)) | (Xcontr(2)<=Xposition(:) & Xposition(:)<Xcontr(3)) | (Xcontr(4)<=Xposition(:))).*rho.*g.*thick(1:2:nods*2).*s(2:2:nods*2).*melted; % basalsliding

% %%%%Sliding on continental shelf independent of T
% uslidebar=-C_sliding1.*((Xcontr(1)<=Xposition(1:nel) & Xposition(1:nel)<Xcontr(2)) | (Xcontr(3)<=Xposition(1:nel) & Xposition(1:nel)<Xcontr(4)))...
% .*rho.*g.*thickbar.*sxbar.*meltedbar ...
% -C_sliding2.*((Xposition(1:nel)<Xcontr(1)) | (Xcontr(2)<=Xposition(1:nel) & Xposition(1:nel)<Xcontr(3))).*rho.*g.*thickbar.*sxbar.*meltedbar ...
% -C_sliding2.*(Xcontr(4)<=Xposition(1:nel)).*rho.*g.*thickbar.*sxbar; % basalsliding
% 
% 
% uslidenode=-C_sliding1.*((Xcontr(1)<=Xposition(:) & Xposition(:)<Xcontr(2)) | (Xcontr(3)<=Xposition(:) & Xposition(:)<Xcontr(4)))...
% .*rho.*g.*thick(1:2:nods*2).*s(2:2:nods*2).*melted ...
% -C_sliding2.*((Xposition(:)<Xcontr(1)) | (Xcontr(2)<=Xposition(:) & Xposition(:)<Xcontr(3))).*rho.*g.*thick(1:2:nods*2).*s(2:2:nods*2).*melted ...
% -C_sliding2.*(Xcontr(4)<=Xposition(:)).*rho.*g.*thick(1:2:nods*2).*s(2:2:nods*2); % basalsliding
% 
% 
% %%uslidenode(2:nods-1)=uslidenode(2:nods-1).*(meltedbar(1:nods-2) | meltedbar(2:nods-1) ); % prohibit sliding at isolated nodes
% %uslidenode(2:nods)=(barren(1:2:nods*2-3)==0 & barren(3:2:nods*2-1)==1).*uslidenode(1:nods-1) ...
% %   + (~(barren(1:2:nods*2-3)==0 & barren((3:2:nods*2-1)==1)).*uslidenode(2:nods);
% %Byron fix on below logic so that either/any terminus and converging terminii included... note: no limitation on isolated melted sliding
% uslidenode(2:nods-1)=(barren(1:2:nods*2-5)==0 & barren(3:2:nods*2-3)==1).*uslidenode(1:nods-2) ...
%    + (barren(3:2:nods*2-3)==barren(4:2:nods*2-2)).*uslidenode(2:nods-1) ...
%    + (~(barren(3:2:nods*2-3)==barren(4:2:nods*2-2)) & (barren(1:2:nods*2-5)==1 ...
%    & barren(4:2:nods*2-2)==0)).*uslidenode(3:nods) ...
%    + ((barren(1:2:nods*2-5)==0 & barren(3:2:nods*2-3)==1 & barren(5:2:nods*2-1)==0) ...
%    & (~(barren(3:2:nods*2-3)==barren(4:2:nods*2-2)))).*(uslidenode(3:nods)+uslidenode(1:nods-2));
%    
% 
% uslidenode(1)=(barren(1)==barren(2))*uslidenode(1) ...
%    + (~(barren(1)==barren(2))).*uslidenode(2);
% 
% uslidenode(nods)=(barren(2*nods-1)==barren(2*nods))*uslidenode(nods) ...
%    + (~(barren(2*nods-1)==barren(2*nods))).*uslidenode(nods-1);
% 
% %Byron fix so that really prohibit sliding at isolated nodes, but after allowing for terminus-upstream-node linking...
% uslidenode(2:nods-1)=uslidenode(2:nods-1)...
% .*( (melted(1:nods-2) & melted(2:nods-1)) | (melted(2:nods-1) & melted(3:nods)) | (Xcontr(4)<=Xposition(2:nods-1))); % prohibit sliding at isolated nodes except on continental shelf
% uslidenode(1)=uslidenode(1).*(melted(1) & melted(2) ); % prohibit sliding at isolated nodes
% uslidenode(nods)=uslidenode(nods).*( (melted(nods-1) & melted(nods)) | (Xcontr(4)<=Xposition(nods)) ); % prohibit sliding at isolated nodes
% %



%%%%From divide to onset has T dependence with C1 rate,
%%%%then transition zone through length of present IS independent of T at C2 and finally
%%%%from present grounding line to end of domain independent of T at C3 rate...
% uslidebar=-C_sliding1.*(Xposition(1:nel)<=Xcontr(1))...
% .*rho.*g.*thickbar.*sxbar.*meltedbar ...
% -C_sliding2.*((Xposition(1:nel)<=Xcontr(2)) & (Xcontr(1)<Xposition(1:nel)))...
% .*rho.*g.*thickbar.*sxbar ...
% -C_sliding3.*(Xcontr(2)<Xposition(1:nel)).*rho.*g.*thickbar.*sxbar; % basalsliding
% 
% 
% uslidenode=-C_sliding1.*(Xposition(:)<=Xcontr(1))...
% .*rho.*g.*thick(1:2:nods*2).*s(2:2:nods*2).*melted ...
% -C_sliding2.*((Xposition(:)<=Xcontr(2)) & (Xcontr(1)<Xposition(:)))...
% .*rho.*g.*thick(1:2:nods*2).*s(2:2:nods*2) ...
% -C_sliding3.*(Xcontr(2)<Xposition(:)).*rho.*g.*thick(1:2:nods*2).*s(2:2:nods*2); % basalsliding
% 
% 
% 
% %Byron fix on below logic so that either/any terminus and converging terminii included... note: no limitation on isolated melted sliding
% uslidenode(2:nods-1)=(barren(1:2:nods*2-5)==0 & barren(3:2:nods*2-3)==1).*uslidenode(1:nods-2) ...
%    + (barren(3:2:nods*2-3)==barren(4:2:nods*2-2)).*uslidenode(2:nods-1) ...
%    + (~(barren(3:2:nods*2-3)==barren(4:2:nods*2-2)) & (barren(1:2:nods*2-5)==1 ...
%    & barren(4:2:nods*2-2)==0)).*uslidenode(3:nods) ...
%    + ((barren(1:2:nods*2-5)==0 & barren(3:2:nods*2-3)==1 & barren(5:2:nods*2-1)==0) ...
%    & (~(barren(3:2:nods*2-3)==barren(4:2:nods*2-2)))).*(uslidenode(3:nods)+uslidenode(1:nods-2));
%    
% 
% uslidenode(1)=(barren(1)==barren(2))*uslidenode(1) ...
%    + (~(barren(1)==barren(2))).*uslidenode(2);
% 
% uslidenode(nods)=(barren(2*nods-1)==barren(2*nods))*uslidenode(nods) ...
%    + (~(barren(2*nods-1)==barren(2*nods))).*uslidenode(nods-1);
% 
% %Byron fix so that prohibit sliding at isolated nodes, but after allowing for terminus-upstream-node linking...
% uslidenode(2:nods-1)=uslidenode(2:nods-1)...
% .*( (melted(1:nods-2) & melted(2:nods-1)) | (melted(2:nods-1) & melted(3:nods)) | (Xcontr(1)<Xposition(2:nods-1))); % prohibit sliding at isolated nodes except in T indep zones
% uslidenode(1)=uslidenode(1).*(melted(1) & melted(2) ); % prohibit sliding at isolated nodes
% uslidenode(nods)=uslidenode(nods).*( (melted(nods-1) & melted(nods)) | (Xcontr(1)<Xposition(nods)) ); % prohibit sliding at isolated nodes
%

for n=1:icelev
u_total(:,n)=uslidenode(:)+udefnode(:,n);	
end
